/* ***** JSQLConnect Examples ******

Overview
--------
This sample applet demonstrates using JSQLConnect to create and populate a table then
fetch and display the data. Connections are aquired through driver manager.

Steps
-----
1. Load the JSQLConnect JDBC Driver.
2. Make a JDBC connection using the JDBC Driver Manager.
3. Create and populate a table.
4. Display the rows from the table.
5. Close the connection.

Requires
--------
1. Microsoft SQL Server is up and running.
2. The datasource, user and password in jdbc:JSQLConnect://localhost/database=master/user=sa/password=secret are valid
3. ExampleApplet.class and JSQLConnect.jar are in the web server root
4. JSQLConnect.jar is specified in the applet's HTML archive tag.

Compile & Run
-------------
Locate JSQLConnect.jar in the JSQLConnect download or distribution and copy it to this
examples directory.

Compile the example at the command line with:-
javac ExampleApplet

Run the example in a web browser with:-
http://yourWebServer/ExampleApplet.html

The results of the result query will be displayed in the web browser.
*/

import java.awt.*;
import java.applet.*;
import java.sql.*;
import java.util.Properties;
import java.net.*;
import java.io.*;

public class ExampleApplet extends Applet {
  private Connection con;
  private TextField txtLog;
  private java.awt.List lstDisplay;
  private Driver driver;
  private final String TABLE_NAME = "TEST_TABLE";

  public void init() {
    buildUI();
    if (!loadJDBCDriver())
      return;
    if (!connectToDatabase())
      return;
    displayTable();
  }

  private boolean loadJDBCDriver() {
    try  {
      driver = (Driver) Class.forName("com.jnetdirect.jsql.JSQLDriver").newInstance();
      log("Loaded driver OK");
      return true;
    }
    catch (Exception e) {
      log("Cannot load the driver, reason:"+e.toString() +
          "Probably the JSQLConnect.jar is not in the web server root");
      return false;
    }
  }

  private boolean connectToDatabase() {
    String sHost  = getCodeBase().getHost();  // Get the address of the web server - this is the only connection an applet can make
    String connectStr = "jdbc:JSQLConnect://"+sHost+"/database=master/user=sa/password=secret";
    try  {
      con = driver.connect(connectStr, new Properties());
      log("Connected OK to "+connectStr);
      return true;
    }
    catch (SQLException e) {
      log("Cannot connect to "+connectStr+", reason:"+e.toString());
      return false;
    }
  }

  private void populateTable() throws SQLException {
    log("Creating table ..");
    Statement s = con.createStatement();
    try {
      s.executeUpdate("DROP TABLE "+TABLE_NAME);
    }
    catch (SQLException e) {}

    s.executeUpdate("CREATE TABLE "+TABLE_NAME+" (COL1 INTEGER, COL2 VARCHAR(10))");

    log("Populating table rows ..");
    for (int i=0; i<10; i++) {
      s.executeUpdate("INSERT INTO "+TABLE_NAME+" (COL1, COL2) VALUES ("+i+", 'VALUE"+ i+"')");
    }
  }

  private void displayTable() {
    try {
      log("Displaying table rows ..");
      Statement s = con.createStatement();
      ResultSet rs = s.executeQuery("SELECT * FROM "+TABLE_NAME);
      ResultSetMetaData dbMeta = rs.getMetaData();
      int nColumns = dbMeta.getColumnCount();
      while (rs.next()) {
        String rowData = "";
        for (int i = 0; i<nColumns; i++) {
          rowData += rs.getString(i+1)+"   ";
        }
        lstDisplay.add(rowData);
      }
    }
    catch (SQLException e) {
      log("SQL Error, reason:"+e.toString());
    }
  }

  public void destroy() {
    if (con != null) {
      try {
        con.close();
        con = null;
      } catch (SQLException e) {
        log("Failed to close connection:"+e.toString());
      }
    }
  }

  private void buildUI() {
    setLayout(null);
    int nWidth = (bounds().width * 95) / 100;
    int nHeight = (bounds().height * 95) / 100;
    int y = 4;
    int w = bounds().width-8;
    int h = bounds().height-12;

    txtLog = new TextField();
    txtLog.resize(w, 24);
    txtLog.move(4, y);
    add(txtLog);
    y += 28;

    lstDisplay = new java.awt.List();
    lstDisplay.resize(w, h-24);
    lstDisplay.move(4, y);
    add(lstDisplay);
  }

  private void log(String s) {
    if (txtLog != null)
      txtLog.setText(s);
    System.out.println(s);
  }

  public void start() {
  }

  public void stop() {
  }
}
