<%
/* ***** JSQLConnect Examples ******

Overview
--------
This sample JSP demonstrates using JSQLConnect to create a connection pool for use
by a JSP. A singleton instance of the pool is created and each time the JSP page is
requested by a client a connection from the pool is used. When the page invocation
is complete the connection is returned to the pool.

In practice the database name, user, password etc would not be hard coded. They are hard coded
here only to simplify the example code.

Alternativly, your servlet/JSP engine may support one or either of:-

1. The JSQLPoolingDataSource datasource may be bound to a JNDI datasource within the servlet
engine's datasources configuration. In this cases the pooling is still managed by the JSQLConnect
driver and you may specify values for any JSQLPoolingDataSource property.

2. You can create a connection pool managed by the servlet engine. Such a configuration would
use the JSQLConnect driver but the pool would be managed by the servlet engine.

Check your servlet engine's datasource configuration documentation for more details.

Steps
-----
1. Create a pooling data source
2. Create and populate a table
3. Display the rows from the table
4. Close the connection

Requires
--------
1. Microsoft SQL Server be up and running.
2. The datasource, user and password in jdbc:JSQLConnect://localhost/database=master/user=sa/password=secret are valid
3. JSQLConnect.jar is in the classpath of your JSP engine.
   For example, if you are using Apache Tomcat 4.x JSQLConnect.jar should be in %CATALINA_HOME%\common\lib
   If you are using another servlet engine please consult that product's documentation regarding
   deployment of 3rd party libraries.
4. Your servlet engine and web server are running.

Run the JSP
-------------
There is no need to compile a JSP.

Deploy the JSP. If you are using Tomcat 4.x :-
Copy ExampleJSPWithPooling.jsp to %CATALINA_HOME%/webapps/examples/jsp

The specific URL to run the example depends on the servlet engine you are using.
If you are using Tomcat 4.x run the example at a web browser with:-
http://localhost:8080/examples/jsp/ExampleJSPWithPooling.jsp

The results of the result query will be displayed.
*/
%>

<html>
<head>
<basefont face="Arial">
</head>
<body>
<%@ page language="java" import="java.sql.*,com.jnetdirect.jsql.JSQLPoolingDataSource" %>

<%!
static JSQLPoolingDataSource poolingDataSource;
%>

<%! public void jspInit() {
      poolingDataSource = new JSQLPoolingDataSource();
      poolingDataSource.setServerName("localhost");
      poolingDataSource.setDatabaseName("master");
      poolingDataSource.setUser("sa");
      poolingDataSource.setPassword("secret");
    }
%>

<h2> JSQLConnect JSP Example</h2>
<table border="2" cellspacing="2" cellpadding="5">

<%
out.println("Pooling DataSource:JSQLPoolingDataSource<br>");
out.println("<br>Table rows display:-<br>");
%>

<tr>
<td><b>Column 1</b></td>
<td><b>Column 2</b></td>
</tr>

<%
// Make the DBMS connection

Connection connection=null;
try {
  connection = poolingDataSource.getConnection();
  // Make the statement
  Statement statement = connection.createStatement();
  // Populate the table
  try {
    statement.executeUpdate("DROP TABLE TEST_TABLE");
  }
  catch (SQLException e) {}
  statement.executeUpdate("CREATE TABLE TEST_TABLE (COL1 INTEGER, COL2 VARCHAR(10))");
  for (int i=0; i<10; i++) {
    statement.executeUpdate("INSERT INTO TEST_TABLE (COL1, COL2) VALUES ("+i+", 'VALUE"+ i+"')");
  }

  // Generate query
  String Query = "SELECT * FROM TEST_TABLE";

  // Get the result and display it
  ResultSet queryResult = statement.executeQuery(Query);

  while(queryResult.next()) {
    out.println("<tr><td>"+queryResult.getString(1)+"</td><td>"+queryResult.getString(2)+"</td></tr>");
  }
  out.println("</table>");

  queryResult.close();
  statement.close();
}
catch (SQLException e) {
  throw e;
}
finally {
  try {
  connection.close();
  } catch (SQLException e) {}
}


out.println("<hr><b>Pool Status:</b><br>"+poolingDataSource.getStatus());
out.println("<hr>");
%>

</table>
</body>
</html>
